<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:office="urn:oasis:names:tc:opendocument:xmlns:office:1.0" xmlns:table="urn:oasis:names:tc:opendocument:xmlns:table:1.0" xmlns:text="urn:oasis:names:tc:opendocument:xmlns:text:1.0" version="1.0" exclude-result-prefixes="office table text">
  <!-- Filter version 2.2.0_qdxml - 2010-12-19 - vjl -->
  <xsl:output method="xml" indent="yes" encoding="UTF-8" omit-xml-declaration="no"/>
    <!-- Match the document base - start the process -->
  <xsl:template match="/">
    <ooo_calc_export scriptVersion="2.2.0_qdxml" scriptUpdate="2011-03-02" scriptURL="http://www.digitalimprint.com/misc/oooexport/" scriptAuthor="vjl">
      <!-- Loop over each table (sheet) in the workbook -->
      <xsl:for-each select="//table:table">
        <!-- Only include tables that have at least one data row to avoid empty sheets in the output -->
        <xsl:if test="./table:table-row[2]">
          <ooo_sheet>
            <xsl:attribute name="num">
              <xsl:value-of select="position()"/>
            </xsl:attribute>
            <xsl:apply-templates select="."/>
            <!-- this will match template for table:table -->
          </ooo_sheet>
        </xsl:if>
      </xsl:for-each>
    </ooo_calc_export>
  </xsl:template>
  <!-- Process individual tables - called from base document matcher -->
  <xsl:template match="table:table">
    <!-- Loop over the rows in the table -->
    <xsl:for-each select="table:table-row">
      <!-- Skip the first row - it is the one containing the column names -->
			<xsl:if test="count(./table:table-cell/text:p)">
				<ooo_row>
					<xsl:call-template name="CellLoop">
						<xsl:with-param name="totalCells" select="count(./table:table-cell)"/>
						<xsl:with-param name="currentColumn" select="1"/>
						<xsl:with-param name="currentCell" select="1"/>
						<xsl:with-param name="currentIteration" select="1"/>
					</xsl:call-template>
				</ooo_row>
			</xsl:if>
    </xsl:for-each>
  </xsl:template>
  <!-- Recursive loop that iterates over the cells in the row while keeping count of the actual column number. -->
  <!-- OOo 'compresses' adjacent duplicated cells, and this expands them back to individual elements. -->
  <xsl:template name="CellLoop">
    <xsl:param name="totalCells"/>
    <xsl:param name="currentColumn"/>
    <xsl:param name="currentCell"/>
    <xsl:param name="currentIteration"/>
    <xsl:if test="$currentCell &lt;= $totalCells">
      <!-- Output the cell contents -->
      <xsl:call-template name="MakeTag">
        <xsl:with-param name="currentColumn" select="$currentColumn"/>
        <xsl:with-param name="tagContentPointer" select="./table:table-cell[position() = $currentCell]"/>
      </xsl:call-template>
      <!-- Decide how to recusively call this template -->
      <xsl:choose>
        <xsl:when test="$currentIteration &lt; ./table:table-cell[position() = $currentCell]/@table:number-columns-repeated">
          <!-- On a 'repeating' cell - call the template again, incrementing the column count, but keep the cell count the same -->
          <xsl:call-template name="CellLoop">
            <xsl:with-param name="totalCells" select="$totalCells"/>
            <xsl:with-param name="currentColumn" select="$currentColumn + 1"/>
            <xsl:with-param name="currentCell" select="$currentCell"/>
            <xsl:with-param name="currentIteration" select="$currentIteration + 1"/>
          </xsl:call-template>
        </xsl:when>
        <xsl:otherwise>
          <!-- On a 'normal' cell - call the template again, incrementing both the column count and the cell count -->
          <xsl:call-template name="CellLoop">
            <xsl:with-param name="totalCells" select="$totalCells"/>
            <xsl:with-param name="currentColumn" select="$currentColumn + 1"/>
            <xsl:with-param name="currentCell" select="$currentCell + 1"/>
            <xsl:with-param name="currentIteration" select="1"/>
          </xsl:call-template>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:if>
  </xsl:template>
  <!-- Convenience template to format the output of an individual cell value -->
  <xsl:template name="MakeTag">
    <xsl:param name="currentColumn"/>
    <xsl:param name="tagContentPointer"/>
    <xsl:text disable-output-escaping="yes">&lt;column_</xsl:text>
    <xsl:value-of select="$currentColumn"/>
    <xsl:text disable-output-escaping="yes">&gt;</xsl:text>
    <xsl:for-each select="$tagContentPointer/text:p">
      <xsl:if test="position() &gt; 1">
        <xsl:call-template name="multilineSeparator" />
      </xsl:if>
      <xsl:value-of select="."/>
    </xsl:for-each>
    <xsl:text disable-output-escaping="yes">&lt;/column_</xsl:text>
    <xsl:value-of select="$currentColumn"/>
    <xsl:text disable-output-escaping="yes">&gt;</xsl:text>
  </xsl:template>
  <!-- Since header cells can potentially repeat, we need to recursively 'walk' over them as well, to ensure we grab the right header for the given column number -->
  

  

  <!-- Cells that contain multiple lines (ctrl-enter) will translate the line endings to this variable in the output -->

  <!-- Default is a 'newline' (empty line), but can be substituted for other strings. -->

  <!-- For example: replace the <xsl:text>\n</xsl:text> segment with <xsl:element name="br"/> to use an XHTML-style break instead -->

  <xsl:template name="multilineSeparator">

    <xsl:text>

</xsl:text>

  </xsl:template>
</xsl:stylesheet>
